@@ -60,6 +60,9 @@ def read_state(yaml_dict, actions: dict = None, prechecks: list = None):
                 elif handler["filter"] == "photo":
                     newHandler = MessageHandler(
                         Filters.photo, actions[handler["action"]])
+                elif handler["filter"] == "sticker":
+                    newHandler = MessageHandler(
+                        Filters.sticker, actions[handler["action"]])
                 elif handler["filter"] == "voice":
                     newHandler = MessageHandler(
                         Filters.voice, actions[handler["action"]])
