@@ -31,15 +31,18 @@ def generate_gif(im1, im2):
     return bio
 
 
-def overlay_images(background, foreground, x_position="left", y_position="up", resize="x"):
-    if resize=="x":
+def overlay_images(background, foreground, x_position="left", y_position="up", resize=True):
+    x_scale_ratio = foreground.size[0]/background.size[0]
+    y_scale_ratio = foreground.size[1]/background.size[1]
+    
+    if x_scale_ratio >= y_scale_ratio:
         scale_ratio = foreground.size[0]/background.size[0]
         background = background.resize(
-            (round(background.size[0]), round(foreground.size[1]*scale_ratio)))
-    elif resize=="y":
+            (foreground.size[0], round(background.size[1]*scale_ratio)))
+    elif x_scale_ratio < y_scale_ratio:
         scale_ratio = foreground.size[1]/background.size[1]
         background = background.resize(
-            (round(background.size[0]*scale_ratio), round(foreground.size[1])))
+            (round(background.size[0]*scale_ratio), foreground.size[1]))
     
     if x_position=="left":
         x_coordinate = 0
